@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "calfw-org" "2.0"
+(define-package "calfw-org" "20251018.1103"
   "Calendar view for org-agenda."
   '((emacs "28.1")
     (calfw "2.0"))
   :url "https://github.com/haji-ali/emacs-calfw"
-  :commit "9cce503eb0e998389485a74b956884d218a960e2"
-  :revdesc "v2.0-0-g9cce503eb0e9"
+  :commit "98279aa29c159159da75c0a990778d848278c482"
+  :revdesc "98279aa29c15"
   :keywords '("calendar" "org")
   :authors '(("SAKURAI Masashi" . "m.sakuraiatkiwanami.net"))
   :maintainers '(("Al Haji-Ali" . "abdo.haji.aliatgmail.com")))
